@@ -68,7 +68,7 @@ def check_validate_no_missing_json_data(app, reporter):
                 reporter.fail(reporter_output, relative_file_path, section.lineno)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.5.0")
 @splunk_appinspect.display(report_display_order=4)
 def check_for_datamodel_acceleration(app, reporter):
