@@ -15,7 +15,7 @@ import os
 import splunk_appinspect
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.0.0")
 @splunk_appinspect.display(report_display_order=6)
 def check_limits_conf(app, reporter):
