@@ -92,7 +92,7 @@ def check_for_hidden_python_files(app, reporter):
                     break
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_for_compiled_python(app, reporter):
     """Check that there are no `.pyc` or `.pyo` files included in the app."""
@@ -104,7 +104,7 @@ def check_for_compiled_python(app, reporter):
         reporter.fail(reporter_output, current_file_relative_path)
 
 
-@splunk_appinspect.tags("cloud", "ast")
+@splunk_appinspect.tags("cloud", "ast", "private_app")
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_for_possible_threading(app, reporter):
     """Check for the use of threading, and multiprocesses. Threading or process must be
@@ -240,7 +240,7 @@ def check_for_file_and_directory_access(app, reporter):
     reporter.ast_manual_check(function_reporter_output, files_with_results)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "security", "ast")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "security", "ast", "private_app")
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_for_python_udp_network_communications(app, reporter):
     """Check for UDP network communication"""
@@ -813,7 +813,7 @@ def check_for_internet_protocols_and_support(app, reporter):
     reporter.ast_manual_check(message, files_with_results)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "security", "ast")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "security", "ast", "private_app")
 @splunk_appinspect.cert_version(min="1.7.0")
 def check_for_root_privilege_escalation(app, reporter):
     """Check possible root privilege escalation"""
