@@ -18,7 +18,7 @@ logger = logging.getLogger(__name__)
 report_display_order = 23
 
 
-@splunk_appinspect.tags("splunk_appinspect", "restmap_config", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "restmap_config", "cloud", "private_app")
 @splunk_appinspect.cert_version(min="1.1.0")
 @splunk_appinspect.display(report_display_order=1)
 def check_restmap_conf_exists(app, reporter):
@@ -42,7 +42,7 @@ def check_rest_handler_scripts_exist(app, reporter):
     do_rest_handler_scripts_check(app, reporter.fail)
 
 
-@splunk_appinspect.tags("cloud", "restmap_config")
+@splunk_appinspect.tags("cloud", "restmap_config", "private_app")
 @splunk_appinspect.cert_version(min="1.6.1")
 def check_rest_handler_scripts_exist_for_cloud(app, reporter):
     """Check that each stanza in restmap.conf has a matching handler script.
@@ -99,7 +99,7 @@ def do_rest_handler_scripts_check(app, reporter_result):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "restmap_config", "cloud", "python3_version"
+    "splunk_appinspect", "restmap_config", "cloud", "python3_version", "private_app"
 )
 @splunk_appinspect.cert_version(min="2.1.0")
 def check_rest_handler_python_executable_exists(app, reporter):
