@@ -24,22 +24,22 @@ class Stack(object):
 
     def has(self, target):
         return target in self._set
-    
+
     @property
     def list(self):
         return self._list
 
     def copy(self, target):
-        self._list = target._list[:]
+        self._list = target._list[:]  # pylint: disable=W0212
         self._set = set()
-        self._set.update(target._set)
+        self._set.update(target._set)  # pylint: disable=W0212
         return self
 
 
 class FileNode(object):
-    '''A class defining the node structure of a python file
+    """A class defining the node structure of a python file
     This structure is used in FileDepManager.
-    '''
+    """
 
     def __init__(self, filepath):
         self.filepath = os.path.abspath(filepath)
@@ -64,7 +64,7 @@ class FileNode(object):
 
     def add_parent(self, parent, stamp=None):
         self._parents.add(parent)
-        parent._children.add(self)
+        parent._children.add(self)  # pylint: disable=W0212
         self.parent_stamps[parent] = stamp
 
     def iter_child(self):
@@ -80,42 +80,48 @@ class FileNode(object):
 
     def has_parent(self, parent):
         return parent in self._parents
-    
+
     def has_child(self, child):
         return child in self._children
 
+
 class Copyable(object):
     def copy(self):
         raise NotImplementedError("copy method should be implemented in Copyable class")
 
 
 class AstVariable(Copyable):
-    '''
+    """
         one variable could have more than one variable types
-    '''
+    """
 
     # some basic variable types
-    STRING_TYPE = 'str'
-    NUMBER_TYPE = 'num'
+    STRING_TYPE = "str"
+    NUMBER_TYPE = "num"
     # class variable
-    CLASS_TYPE = 'instance'
+    CLASS_TYPE = "instance"
     # function variable
-    FUNCTION_TYPE = 'function'
+    FUNCTION_TYPE = "function"
     # module variable
-    MODULE_TYPE = 'module'
+    MODULE_TYPE = "module"
     # builtin variable
-    BUILTIN_TYPE = '__builtin__'
+    BUILTIN_TYPE = "__builtin__"
     # callable function
-    CALLABLE_FUNCTION = 'callable_function'
+    CALLABLE_FUNCTION = "callable_function"
 
-    SPECIAL_TYPES = [STRING_TYPE, NUMBER_TYPE, CLASS_TYPE, FUNCTION_TYPE, MODULE_TYPE, BUILTIN_TYPE, CALLABLE_FUNCTION]
+    SPECIAL_TYPES = [
+        STRING_TYPE,
+        NUMBER_TYPE,
+        CLASS_TYPE,
+        FUNCTION_TYPE,
+        MODULE_TYPE,
+        BUILTIN_TYPE,
+        CALLABLE_FUNCTION,
+    ]
 
     def __init__(
-            self,
-            variable_value_node,
-            variable_type_set,
-            variable_value=None,
-            name=None):
+        self, variable_value_node, variable_type_set, variable_value=None, name=None
+    ):
         # variable name
         self.name = name
         # AST node in ='s right side
@@ -131,45 +137,91 @@ class AstVariable(Copyable):
         self.variable_value = variable_value
 
     def copy(self):
-        copy_variable_value_node, copy_variable_type_set, copy_variable_value = self.variable_value_node, \
-                                                                                copy.deepcopy(self.variable_type_set), \
-                                                                                self.variable_value.copy() if isinstance(self.variable_value, Copyable) else copy.deepcopy(self.variable_value)
-        return AstVariable(copy_variable_value_node, copy_variable_type_set, copy_variable_value, self.name)
+        copy_variable_value_node, copy_variable_type_set, copy_variable_value = (
+            self.variable_value_node,
+            copy.deepcopy(self.variable_type_set),
+            self.variable_value.copy()
+            if isinstance(self.variable_value, Copyable)
+            else copy.deepcopy(self.variable_value),
+        )
+        return AstVariable(
+            copy_variable_value_node,
+            copy_variable_type_set,
+            copy_variable_value,
+            self.name,
+        )
 
     @staticmethod
     def is_class_instance(ast_variable):
-        return isinstance(ast_variable, AstVariable) and (AstVariable.CLASS_TYPE in ast_variable.variable_type_set) and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES)) == 1
+        return (
+            isinstance(ast_variable, AstVariable)
+            and (AstVariable.CLASS_TYPE in ast_variable.variable_type_set)
+            and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES))
+            == 1
+        )
 
     @staticmethod
     def is_string(ast_variable):
-        return isinstance(ast_variable, AstVariable) and (AstVariable.STRING_TYPE in ast_variable.variable_type_set) and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES)) == 1
+        return (
+            isinstance(ast_variable, AstVariable)
+            and (AstVariable.STRING_TYPE in ast_variable.variable_type_set)
+            and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES))
+            == 1
+        )
 
     @staticmethod
     def is_number(ast_variable):
-        return isinstance(ast_variable, AstVariable) and (AstVariable.NUMBER_TYPE in ast_variable.variable_type_set) and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES)) == 1
+        return (
+            isinstance(ast_variable, AstVariable)
+            and (AstVariable.NUMBER_TYPE in ast_variable.variable_type_set)
+            and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES))
+            == 1
+        )
 
     @staticmethod
     def is_function(ast_variable):
-        return isinstance(ast_variable, AstVariable) and (AstVariable.FUNCTION_TYPE in ast_variable.variable_type_set) and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES)) == 1
+        return (
+            isinstance(ast_variable, AstVariable)
+            and (AstVariable.FUNCTION_TYPE in ast_variable.variable_type_set)
+            and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES))
+            == 1
+        )
 
     @staticmethod
     def is_module(ast_variable):
-        return isinstance(ast_variable, AstVariable) and (AstVariable.MODULE_TYPE in ast_variable.variable_type_set) and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES)) == 1
+        return (
+            isinstance(ast_variable, AstVariable)
+            and (AstVariable.MODULE_TYPE in ast_variable.variable_type_set)
+            and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES))
+            == 1
+        )
 
     @staticmethod
     def is_builtin(ast_variable):
-        return isinstance(ast_variable, AstVariable) and (AstVariable.BUILTIN_TYPE in ast_variable.variable_type_set) and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES)) == 1
+        return (
+            isinstance(ast_variable, AstVariable)
+            and (AstVariable.BUILTIN_TYPE in ast_variable.variable_type_set)
+            and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES))
+            == 1
+        )
 
     @staticmethod
     def is_callable_function(ast_variable):
-        return isinstance(ast_variable, AstVariable) and (AstVariable.CALLABLE_FUNCTION in ast_variable.variable_type_set) and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES)) == 1
+        return (
+            isinstance(ast_variable, AstVariable)
+            and (AstVariable.CALLABLE_FUNCTION in ast_variable.variable_type_set)
+            and len(ast_variable.variable_type_set & set(AstVariable.SPECIAL_TYPES))
+            == 1
+        )
 
     @staticmethod
     def is_callable(ast_variable):
-        return AstVariable.is_builtin(ast_variable) or AstVariable.is_callable_function(ast_variable)
+        return AstVariable.is_builtin(ast_variable) or AstVariable.is_callable_function(
+            ast_variable
+        )
+
 
 class AstFunction(Copyable):
-
     def __init__(self, name, root_node, return_value=None):
         self.name = name
         self.root_node = root_node
@@ -183,17 +235,21 @@ class AstFunction(Copyable):
         # return value should be None or AstVariable
         return None if self.return_value is None else self.return_value.copy()
 
+
 class AstClass(Copyable):
 
     # TODO doesn't align with python implementation
-    '''
+    """
         Python won't copy context from super class to current class, just link them together. So If I change a attribute in super class,
         inherited class or instances will also be affected. In current implementation, we could not support this feature, since super class and
         inherited class are isolated environments, they won't affect each other.
 
         Current design facilitate Analyzer's implementation, make code easy to maintain. Need to refactor these logic when necessary
-    '''
-    def __init__(self, name, class_context, function_dict=None, modules=None, namespace=None):
+    """
+
+    def __init__(
+        self, name, class_context, function_dict=None, modules=None, namespace=None
+    ):
         self.name = name
         self.namespace = namespace
         self.class_context = class_context
@@ -206,11 +262,16 @@ class AstClass(Copyable):
         copy_function_dict = {}
         for function_name, function in self.function_dict.items():
             copy_function_dict[function_name] = function
-        return AstClass(self.name, copy_class_context, copy_function_dict, copy.deepcopy(self.modules), self.namespace)
+        return AstClass(
+            self.name,
+            copy_class_context,
+            copy_function_dict,
+            copy.deepcopy(self.modules),
+            self.namespace,
+        )
 
 
 class AstModule(Copyable):
-
     def __init__(self, name, global_map=None, namespace=None):
         self.name = name
         self.namespace = namespace
@@ -224,34 +285,30 @@ class AstModule(Copyable):
 
 
 class AstCallableFunction(Copyable):
-
-    def __init__(self, name, namespace = None):
+    def __init__(self, name, namespace=None):
         self.name = name
         self.namespace = namespace
 
     def action(self, function_node, analyzer, args, keywords, context):
-        '''
+        """
         Simulate function call here, eg: func_name()
         Other arguments are same as below
-        '''
-        pass
+        """
 
     def copy(self):
-        '''Immutable object, return callable function itself'''
+        """Immutable object, return callable function itself"""
         return self
 
 
-'''
-    All builtin functions start with AstBuiltin prefix, they will be collected in ast-analyzer
-'''
+# All builtin functions start with AstBuiltin prefix, they will be collected in ast-analyzer
+
 
 class AstBuiltinFunction(Copyable):
-
     def __init__(self, name):
         self.name = name
 
     def action(self, function_node, analyzer, args, keywords, context):
-        '''
+        """
         Simulate builtin function call here, eg: __import__ function call
 
         :param function_node:   current function node
@@ -262,8 +319,7 @@ class AstBuiltinFunction(Copyable):
         :return:                builtin function's return value, if builtin function doesn't
                                 have any return value, please return a dummy AstVariable,
                                 eg: AstVariable(None, set())
-        '''
-        pass
+        """
 
     def copy(self):
         # immutable object, don't need to create a new object
@@ -271,18 +327,16 @@ class AstBuiltinFunction(Copyable):
 
 
 class AstBuiltinOpenFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'open')
+        AstBuiltinFunction.__init__(self, "open")
 
     def action(self, function_node, analyzer, args, keywords, context):
-        return AstVariable(function_node, {'file'}, None)
+        return AstVariable(function_node, {"file"}, None)
 
 
 class AstBuiltinEvalFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'eval')
+        AstBuiltinFunction.__init__(self, "eval")
 
     def action(self, function_node, analyzer, args, keywords, context):
         # Now eval has no side effect, just return a empty variable
@@ -294,44 +348,51 @@ class AstBuiltinEvalFunction(AstBuiltinFunction):
             except SyntaxError:
                 # bypass unexpected code string
                 pass
-            except:
-                raise
             else:
                 if expr_node:
                     # two possible risky usages
                     # 1. function call
                     # 2. variable assignation
                     ast_node = expr_node.value
-                    return_variable = analyzer._get_variable_from_node(ast_node, context)
+                    return_variable = analyzer._get_variable_from_node(
+                        ast_node, context
+                    )  # pylint: disable=W0212
                     # special check for call nodes, since it is dangerous
                     for node in ast.walk(expr_node):
                         if isinstance(node, ast.Call):
-                            modules = analyzer._get_modules_used_in_ast_name_and_attribute_chain(node, context)
-                            analyzer._update_inverted_index_dict_with_key_set(modules, function_node, analyzer._module_function_call_usage)
+                            modules = analyzer._get_modules_used_in_ast_name_and_attribute_chain(
+                                node, context
+                            )  # pylint: disable=W0212
+                            analyzer._update_inverted_index_dict_with_key_set(
+                                modules,
+                                function_node,
+                                analyzer._module_function_call_usage,
+                            )  # pylint: disable=W0212
                     return return_variable
         return AstVariable(function_node, set(), None)
 
-    def _get_expr_ast_node(self, ast_node):
+    @staticmethod
+    def _get_expr_ast_node(ast_node):
 
         for node in ast.walk(ast_node):
             if isinstance(node, ast.Expr):
                 return node
         return None
 
-    def _get_code_string(self, args, keywords):
+    @staticmethod
+    def _get_code_string(args, keywords):
 
         # First positional argument
         argument = args[0] if args else None
         if AstVariable.is_string(argument):
             return argument.variable_value
-        else:
-            return None
+
+        return None
 
 
 class AstBuiltinExecfileFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'execfile')
+        AstBuiltinFunction.__init__(self, "execfile")
 
     def action(self, function_node, analyzer, args, keywords, context):
         # No side effect in execfile handler
@@ -339,40 +400,37 @@ class AstBuiltinExecfileFunction(AstBuiltinFunction):
 
 
 class AstBuiltinFileFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'file')
+        AstBuiltinFunction.__init__(self, "file")
 
     def action(self, function_node, analyzer, args, keywords, context):
         # No side effect in file handler
-        return AstVariable(function_node, {'file'}, None)
+        return AstVariable(function_node, {"file"}, None)
 
 
 class AstBuiltinMemoryViewFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'memoryview')
+        AstBuiltinFunction.__init__(self, "memoryview")
 
     def action(self, function_node, analyzer, args, keywords, context):
         # No side effect in memoryview handler
-        return AstVariable(function_node, {'memoryview'}, None)
+        return AstVariable(function_node, {"memoryview"}, None)
 
 
 class AstBuiltinImportFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, '__import__')
+        AstBuiltinFunction.__init__(self, "__import__")
 
     def action(self, function_node, analyzer, args, keywords, context):
 
         import_name = self._get_imported_module_name(args, keywords)
         if import_name:
-            module_names = import_name.split('.')
+            module_names = import_name.split(".")
             # use first module name as imported module
             module_name = module_names[0]
             if analyzer.module_manager:
                 modules = analyzer.module_manager.load_modules(module_name)
-                if len(modules) > 0:
+                if modules:
                     # Here `__import__` is very similar to `import`
                     # Only one module should be loaded
                     assert len(modules) == 1
@@ -380,28 +438,28 @@ class AstBuiltinImportFunction(AstBuiltinFunction):
             # collect all possible modules
             module_name_set = set()
             for i in range(len(module_names)):
-                module_string = '.'.join(module_names[0: i + 1])
+                module_string = ".".join(module_names[0 : i + 1])
                 module_name_set.add(module_string)
             return AstVariable(function_node, module_name_set)
-        else:
-            return AstVariable(function_node, set())
 
-    def _get_imported_module_name(self, args, keywords):
-        if len(args) > 0:
+        return AstVariable(function_node, set())
+
+    @staticmethod
+    def _get_imported_module_name(args, keywords):
+        if args:
             arg = args[0]
             if AstVariable.is_string(arg):
                 return arg.variable_value
-        if 'name' in keywords:
-            arg = keywords['name']
+        if "name" in keywords:
+            arg = keywords["name"]
             if AstVariable.is_string(arg):
                 return arg.variable_value
         return None
 
 
 class AstBuiltinGetattrFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'getattr')
+        AstBuiltinFunction.__init__(self, "getattr")
 
     def action(self, function_node, analyzer, args, keywords, context):
 
@@ -414,51 +472,66 @@ class AstBuiltinGetattrFunction(AstBuiltinFunction):
         if len(args) > 2:
             default_value = args[2]
         # then check keyword
-        if 'object' in keywords:
-            node = keywords['object']
-        if 'name' in keywords and AstVariable.is_string(keywords['name']):
-            attribute_name = keywords['name'].variable_value
-        if 'default' in keywords:
-            default_value = keywords['default']
+        if "object" in keywords:
+            node = keywords["object"]
+        if "name" in keywords and AstVariable.is_string(keywords["name"]):
+            attribute_name = keywords["name"].variable_value
+        if "default" in keywords:
+            default_value = keywords["default"]
         # attribute name and node are available
         if attribute_name and node:
             # if it is a class
-            if AstVariable.is_class_instance(node) and attribute_name in node.variable_value.class_context.variable_map:
+            if (
+                AstVariable.is_class_instance(node)
+                and attribute_name in node.variable_value.class_context.variable_map
+            ):
                 return node.variable_value.class_context.variable_map[attribute_name]
-            elif isinstance(node, AstClass) and attribute_name in node.class_context.variable_map:
-                return node.class_context.variable_map[attribute_name]
-            # if it is a module
-            elif AstVariable.is_module(node) and attribute_name in node.variable_value.global_map:
-                return node.variable_value.global_map[attribute_name]
-            elif isinstance(node, AstModule) and attribute_name in node.global_map:
-                return node.global_map[attribute_name]
-            else:
-                if default_value:
-                    return default_value
-                else:
-                    type_set = set()
-                    # collect modules used in variable
-                    if isinstance(node, AstVariable):
-                        for variable_type in (node.variable_type_set - set(AstVariable.SPECIAL_TYPES)):
-                            type_set.add(variable_type + '.' + attribute_name)
-                        if AstVariable.is_class_instance(node):
-                            for variable_type in (node.variable_value.modules - set(AstVariable.SPECIAL_TYPES)):
-                                type_set.add(variable_type + '.' + attribute_name)
-                    # collect modules used in AstClass
-                    elif isinstance(node, AstClass):
-                        for variable_type in (node.modules - set(AstVariable.SPECIAL_TYPES)):
-                            type_set.add(variable_type + '.' + attribute_name)
 
-                    return AstVariable(function_node, type_set, None)
+            if (
+                isinstance(node, AstClass)
+                and attribute_name in node.class_context.variable_map
+            ):
+                return node.class_context.variable_map[attribute_name]
+
+            # if it is a module
+            if (
+                AstVariable.is_module(node)
+                and attribute_name in node.variable_value.global_map
+            ):
+                return node.variable_value.global_map[attribute_name]
+
+            if isinstance(node, AstModule) and attribute_name in node.global_map:
+                return node.global_map[attribute_name]
+
+            if default_value:
+                return default_value
+
+            type_set = set()
+            # collect modules used in variable
+            if isinstance(node, AstVariable):
+                for variable_type in node.variable_type_set - set(
+                    AstVariable.SPECIAL_TYPES
+                ):
+                    type_set.add(variable_type + "." + attribute_name)
+                if AstVariable.is_class_instance(node):
+                    for variable_type in node.variable_value.modules - set(
+                        AstVariable.SPECIAL_TYPES
+                    ):
+                        type_set.add(variable_type + "." + attribute_name)
+            # collect modules used in AstClass
+            elif isinstance(node, AstClass):
+                for variable_type in node.modules - set(AstVariable.SPECIAL_TYPES):
+                    type_set.add(variable_type + "." + attribute_name)
+
+            return AstVariable(function_node, type_set, None)
 
         # return a variable without any types
         return AstVariable(function_node, set(), None)
 
 
 class AstBuiltinSetattrFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'setattr')
+        AstBuiltinFunction.__init__(self, "setattr")
 
     def action(self, function_node, analyzer, args, keywords, context):
 
@@ -471,12 +544,12 @@ class AstBuiltinSetattrFunction(AstBuiltinFunction):
         if len(args) > 2:
             value = args[2]
         # then check keywords
-        if 'object' in keywords:
-            node = keywords['object']
-        if 'name' in keywords and AstVariable.is_string(keywords['name']):
-            attribute_name = keywords['name'].variable_value
-        if 'value' in keywords:
-            value = keywords['value']
+        if "object" in keywords:
+            node = keywords["object"]
+        if "name" in keywords and AstVariable.is_string(keywords["name"]):
+            attribute_name = keywords["name"].variable_value
+        if "value" in keywords:
+            value = keywords["value"]
         if attribute_name and node:
             if AstVariable.is_class_instance(node):
                 node.variable_value.class_context.variable_map[attribute_name] = value
@@ -491,9 +564,8 @@ class AstBuiltinSetattrFunction(AstBuiltinFunction):
 
 
 class AstBuiltinDelattrFunction(AstBuiltinFunction):
-
     def __init__(self):
-        AstBuiltinFunction.__init__(self, 'delattr')
+        AstBuiltinFunction.__init__(self, "delattr")
 
     def action(self, function_node, analyzer, args, keywords, context):
 
@@ -502,10 +574,10 @@ class AstBuiltinDelattrFunction(AstBuiltinFunction):
             node = args[0]
         if len(args) > 1 and AstVariable.is_string(args[1]):
             attribute_name = args[1].variable_value
-        if 'object' in keywords:
-            node = keywords['object']
-        if 'name' in keywords and AstVariable.is_string(keywords['name']):
-            attribute_name = keywords['name'].variable_value
+        if "object" in keywords:
+            node = keywords["object"]
+        if "name" in keywords and AstVariable.is_string(keywords["name"]):
+            attribute_name = keywords["name"].variable_value
 
         if node and attribute_name:
             if AstVariable.is_class_instance(node):
@@ -525,7 +597,6 @@ class AstBuiltinDelattrFunction(AstBuiltinFunction):
 
 
 class AstBuiltinSuperFunction(AstBuiltinFunction):
-
     def __init__(self):
         AstBuiltinFunction.__init__(self, "super")
 
@@ -541,27 +612,32 @@ class AstBuiltinSuperFunction(AstBuiltinFunction):
                 module_set |= arg.modules
             elif isinstance(arg, AstBuiltinFunction):
                 # `builtin type` and `builtin.func_name`
-                module_set |= {AstVariable.BUILTIN_TYPE,
-                               AstVariable.BUILTIN_TYPE + '.' + arg.name}
-            if getattr(arg, 'namespace', None):
-                names = arg.namespace.split('.')
+                module_set |= {
+                    AstVariable.BUILTIN_TYPE,
+                    AstVariable.BUILTIN_TYPE + "." + arg.name,
+                }
+            if getattr(arg, "namespace", None):
+                names = arg.namespace.split(".")
                 for j in range(len(names)):
-                    module_string = '.'.join(names[: j + 1])
+                    module_string = ".".join(names[: j + 1])
                     module_set.add(module_string)
         module_set -= set(AstVariable.SPECIAL_TYPES)
         return AstVariable(function_node, module_set)
 
 
 class AstBuiltinApplyFunction(AstBuiltinFunction):
-
     def __init__(self):
         AstBuiltinFunction.__init__(self, "apply")
 
     def action(self, function_node, analyzer, args, keywords, context):
         if function_node.args:
-            type_set = analyzer._get_modules_used_in_ast_name_and_attribute_chain(function_node.args[0], context)
+            type_set = analyzer._get_modules_used_in_ast_name_and_attribute_chain(
+                function_node.args[0], context
+            )  # pylint: disable=W0212
             # update possible function call usages
-            analyzer._update_inverted_index_dict_with_key_set(type_set, function_node, analyzer._module_function_call_usage)
+            analyzer._update_inverted_index_dict_with_key_set(
+                type_set, function_node, analyzer._module_function_call_usage
+            )  # pylint: disable=W0212
         # return a variable without any types
         return AstVariable(function_node, set(), None)
 
@@ -569,17 +645,17 @@ class AstBuiltinApplyFunction(AstBuiltinFunction):
 class AstContext(Copyable):
 
     # parse from top to bottom
-    PARSING_MODE = 'parsing'
+    PARSING_MODE = "parsing"
     # simulate function calls
-    SIMULATE_MODE = 'simulate'
+    SIMULATE_MODE = "simulate"
     # collect all possible variable types in this mode, used to handle if-else statement
-    COLLECT_MODE = 'collect'
+    COLLECT_MODE = "collect"
 
     def __init__(self, level, root_node, parent_context=None):
         # variable name to AstVariable
         self.variable_map = {}
         # current namespace
-        self.namespace = ''
+        self.namespace = ""
 
         self.level = level
         self.root_node = root_node
